"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "PinInputField", {
  enumerable: true,
  get: function () {
    return _PinInputField.default;
  }
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _Stack = require("../../primitives/Stack");

var _hooks = require("../../../hooks");

var _FormControl = require("../FormControl");

var _reactNative = require("react-native");

var _isNil = _interopRequireDefault(require("lodash/isNil"));

var _Context = require("./Context");

var _PinInputField = _interopRequireDefault(require("./PinInputField"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const PinInput = ({
  children,
  ...props
}) => {
  const {
    manageFocus,
    defaultValue,
    value,
    space,
    onChange,
    ...newProps
  } = (0, _hooks.usePropsConfig)('PinInput', props);

  const formControlContext = _react.default.useContext(_FormControl.FormControlContext);

  const RefList = [];

  const setRefList = (ref, index) => {
    RefList[index] = ref;
  };

  const [pinInputValue, setPinInputValue] = _react.default.useState(value || defaultValue);

  const handleChange = (newValue, fieldIndex) => {
    let temp = pinInputValue && [...pinInputValue] || [];
    temp[fieldIndex] = newValue;
    setPinInputValue(temp.join(''));
    onChange && onChange(temp.join(''));
    if (!(0, _isNil.default)(newValue) && manageFocus && fieldIndex + 1 < RefList.length) RefList[fieldIndex + 1].current.focus();
    if ((0, _isNil.default)(newValue) && manageFocus && fieldIndex - 1 > -1) RefList[fieldIndex - 1].current.focus();
    return temp.join('');
  };

  const handleMultiValueChange = (newValue, fieldIndex) => {
    const pinFieldLength = RefList.length;
    const newValueLength = newValue.length;

    if (newValueLength >= pinFieldLength && newValueLength > 2) {
      let splicedValue = newValue ? [...newValue] : [];
      splicedValue.splice(pinFieldLength);
      RefList[pinFieldLength - 1].current.focus();
      setPinInputValue(splicedValue.join(''));
      onChange && onChange(splicedValue.join(''));
    }

    if (_reactNative.Platform.OS === 'android' && newValue) {
      const temp = pinInputValue ? [...pinInputValue] : [];
      temp[fieldIndex] = JSON.stringify(parseInt(newValue, 10) % 10);
      if (newValue && manageFocus && fieldIndex + 1 < RefList.length) RefList[fieldIndex + 1].current.focus(); // Backward focus is handled by handle change function.

      setPinInputValue(temp.join(''));
      onChange && onChange(temp.join(''));
    }
  };

  const indexSetter = allChildren => {
    let pinInputFiledCounter = -1;
    return _react.default.Children.map(allChildren, child => {
      if (child.type.name !== 'PinInputFiled') return child;else {
        pinInputFiledCounter++;
        return /*#__PURE__*/_react.default.cloneElement(child, {
          fieldIndex: pinInputFiledCounter
        }, child.props.children);
      }
    });
  };

  return /*#__PURE__*/_react.default.createElement(_Context.PinInputContext.Provider, {
    value: { ...formControlContext,
      ...newProps,
      setRefList,
      handleChange,
      handleMultiValueChange,
      value: pinInputValue
    }
  }, children && /*#__PURE__*/_react.default.createElement(_Stack.HStack, {
    flexDirection: "row",
    space: space
  }, indexSetter(children)));
};

var _default = PinInput;
exports.default = _default;
//# sourceMappingURL=index.js.map