"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _useFadeTransition = require("../../components/composites/Transitions/useFadeTransition");

var _Context = require("./Context");

var _View = _interopRequireDefault(require("../../components/primitives/View"));

var _utils = require("./utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const PopoverProvider = ({
  children
}) => {
  const [popoverItem, setPopoverItem] = _react.default.useState(null);

  const [config, setConfig] = _react.default.useState({
    triggerRef: null,
    placeOverTriggerElement: undefined,
    onClose: null,
    animationDuration: 200
  });

  const [state, setState] = _react.default.useState({
    elementX: 0,
    elementY: 0,
    elementWidth: 0,
    elementHeight: 0
  });

  const [triggerElementDims, setTriggerElementDims] = _react.default.useState({
    x: 0,
    y: 0,
    width: 0,
    height: 0
  });

  const getElementDims = ({
    nativeEvent
  }) => {
    if (nativeEvent && nativeEvent.layout) {
      setState({
        elementX: nativeEvent.layout.x,
        elementY: nativeEvent.layout.y,
        elementWidth: nativeEvent.layout.width,
        elementHeight: nativeEvent.layout.height
      });
    }
  };

  _react.default.useEffect(() => {
    if (config.triggerRef && config.triggerRef.current) {
      config.triggerRef.current.measure((x, y, width, height) => {
        setTriggerElementDims({
          x,
          y,
          width,
          height
        });
      });
    }
  }, [config.triggerRef]);

  let positions = (0, _utils.getCoordinates)(triggerElementDims.y, triggerElementDims.x, state.elementWidth, state.elementHeight, triggerElementDims.width, triggerElementDims.height, config.placeOverTriggerElement);
  const {
    fadeValue,
    fadeIn,
    fadeOut
  } = (0, _useFadeTransition.useFadeTransition)(config.animationDuration);

  let providerStyle = _reactNative.StyleSheet.create({
    wrapper: {
      position: 'absolute',
      top: 0,
      bottom: 0,
      right: 0,
      left: 0,
      zIndex: 999
    }
  });

  popoverItem ? fadeIn() : fadeOut();
  return /*#__PURE__*/_react.default.createElement(_Context.PopoverContext.Provider, {
    value: {
      setPopoverItem,
      defaultConfig: config,
      setConfig,
      parentComponentConfig: config.parentComponentConfig
    }
  }, children, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    nativeID: "popover-provider",
    style: [providerStyle.wrapper, {
      opacity: fadeValue
    }],
    pointerEvents: popoverItem ? 'auto' : 'none'
  }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableWithoutFeedback, {
    onPress: () => {
      setPopoverItem(null);
      config.onClose && config.onClose();
    }
  }, /*#__PURE__*/_react.default.createElement(_View.default, {
    style: providerStyle.wrapper
  })), /*#__PURE__*/_react.default.createElement(_View.default, {
    zIndex: 99999,
    onLayout: getElementDims,
    position: "absolute",
    style: positions
  }, popoverItem)));
};

var _default = PopoverProvider;
exports.default = _default;
//# sourceMappingURL=PopoverProvider.js.map