"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AlertDescription = exports.AlertTitle = exports.Alert = void 0;

var _tools = require("../tools");

function getBg(props) {
  let {
    theme,
    status
  } = props;
  status = (0, _tools.getColorScheme)(props, status);
  const lightBg = (0, _tools.getColor)(theme, "".concat(status, ".100"), status); // const darkBg = getColor(theme, `${status}.800`, status);

  const darkBg = (0, _tools.transparentize)("".concat(status, ".300"), 0.2)(theme);
  return (0, _tools.mode)(lightBg, darkBg)(props);
}

const variantSubtle = props => {
  let {
    status
  } = props;
  status = (0, _tools.getColorScheme)(props, status);
  let a = {
    border: 6,
    borderColor: 'transparent',
    bg: getBg(props),
    iconColor: (0, _tools.mode)("".concat(status, ".700"), "".concat(status, ".200"))(props),
    textColor: (0, _tools.mode)('gray', 'white')(props)
  };
  return a;
};

const variantSolid = props => {
  let {
    status
  } = props;
  status = (0, _tools.getColorScheme)(props, status);
  return {
    border: 6,
    borderColor: 'transparent',
    bg: getBg(props),
    iconColor: (0, _tools.mode)("".concat(status, ".700"), "".concat(status, ".200"))(props),
    textColor: (0, _tools.mode)('gray', 'white')(props)
  };
};

const variantLeftAccent = props => {
  let {
    status,
    theme
  } = props;
  status = (0, _tools.getColorScheme)(props, status);
  return {
    border: 6,
    bg: getBg(props),
    iconColor: (0, _tools.mode)("".concat(status, ".700"), "".concat(status, ".200"))(props),
    textColor: (0, _tools.mode)('gray', 'white')(props),
    borderColor: 'transparent',
    borderLeftColor: theme.colors[status][100]
  };
};

const variantTopAccent = props => {
  let {
    status,
    theme
  } = props;
  status = (0, _tools.getColorScheme)(props, status);
  return {
    border: 6,
    borderColor: 'transparent',
    borderTopColor: theme.colors[status][100],
    bg: getBg(props),
    iconColor: (0, _tools.mode)("".concat(status, ".700"), "".concat(status, ".200"))(props),
    textColor: (0, _tools.mode)('gray', 'white')(props)
  };
};

const variants = {
  'subtle': variantSubtle,
  'solid': variantSolid,
  'left-accent': variantLeftAccent,
  'top-accent': variantTopAccent
};
const defaultAlertProps = {
  status: 'default',
  variant: 'subtle',
  p: 3,
  borderRadius: 'md'
};
const Alert = {
  defaultProps: defaultAlertProps,
  variants
}; // AlertTitle

exports.Alert = Alert;
const defaultAlertTitleProps = {
  fontSize: 'lg',
  fontWeight: 'bold'
};
const AlertTitle = {
  defaultProps: defaultAlertTitleProps
}; // AlertDescription

exports.AlertTitle = AlertTitle;
const defaultAlertDescriptionProps = {
  fontSize: 'lg'
};
const AlertDescription = {
  defaultProps: defaultAlertDescriptionProps
};
exports.AlertDescription = AlertDescription;
//# sourceMappingURL=alert.js.map